# Regular regexes

The goal of this repo is avoid having to look up commonly used regexes, but have them all bundled in a single place.

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Usage

Install the package using `pip install regular_regexes`

Import it:

`from rre import rre` (goal is to stay as close as possible to the default regex package)

